#!/bin/bash

# $1 目标目录
# ./rsync_background.sh /mnt/a/a/a

TARGET_DIR=$1
ENABLE=$2
if [ -z "$TARGET_DIR" ];then
    exit 1
fi
. /etc/default/cineverse

if [ ! -d "$JELLYFIN_DATA_DIR" ];then
  JELLYFIN_DATA_DIR=/var/lib/cineverse
fi

setDir(){
    NAME=cineverse
    JELLYFIN_USER=${JELLYFIN_USER:-cineverse}
    RENDER_GROUP=${RENDER_GROUP:-render}
    VIDEO_GROUP=${VIDEO_GROUP:-video}

    # Data directories for program data (cache, db), configs, and logs
    PROGRAMDATA=${JELLYFIN_DATA_DIRECTORY-/var/lib/$NAME}
    CONFIGDATA=${JELLYFIN_CONFIG_DIRECTORY-/etc/$NAME}
    LOGDATA=${JELLYFIN_LOG_DIRECTORY-/var/log/$NAME}
    CACHEDATA=${JELLYFIN_CACHE_DIRECTORY-/var/cache/$NAME}

#    echo ${JELLYFIN_USER}
#    echo ${RENDER_GROUP}
#    echo ${VIDEO_GROUP}
#
#    echo ${PROGRAMDATA}
#    echo ${CONFIGDATA}
#    echo ${LOGDATA}
#    echo ${CACHEDATA}

    # ensure $PROGRAMDATA exists
    if [[ ! -d $PROGRAMDATA ]]; then
      mkdir $PROGRAMDATA
    fi
    # ensure $CONFIGDATA exists
    if [[ ! -d $CONFIGDATA ]]; then
      mkdir $CONFIGDATA
    fi
    # ensure $LOGDATA exists
    if [[ ! -d $LOGDATA ]]; then
      mkdir $LOGDATA
    fi
    # ensure $CACHEDATA exists
    if [[ ! -d $CACHEDATA ]]; then
      mkdir $CACHEDATA
    fi
    # Ensure permissions are correct on all config directories
    chown -R ${JELLYFIN_USER} $PROGRAMDATA $CONFIGDATA $LOGDATA $CACHEDATA
    chgrp adm $PROGRAMDATA $CONFIGDATA $LOGDATA $CACHEDATA
    chmod 0750 $PROGRAMDATA $CONFIGDATA $LOGDATA $CACHEDATA
}

if [ "$TARGET_DIR/cineverse" == "$JELLYFIN_DATA_DIR" ]; then
    setDir

    STATUS2=$(systemctl is-active cineverse.service)
    if [[ "$STATUS2" != "active" && "$ENABLE" -eq 1 ]]; then
      systemctl start cineverse.service
    fi

    exit 0
fi

STATUS=$(systemctl is-active cineverse.service)
if [ $STATUS == "active" ]; then
  systemctl stop cineverse.service
fi

echo "$JELLYFIN_DATA_DIR"
echo "$TARGET_DIR/"
rsync -aIP --remove-source-files "$JELLYFIN_DATA_DIR" "$TARGET_DIR/" && find "$JELLYFIN_DATA_DIR" -type d -empty -delete

if [ $? -eq 0 ]; then
    DATA_DIR_SET=JELLYFIN_DATA_DIR=\"$TARGET_DIR/cineverse\"
    LOG_DIR_SET=JELLYFIN_LOG_DIR=\"$TARGET_DIR/cineverse/log\"
    CACHE_DIR_SET=JELLYFIN_CACHE_DIR=\"$TARGET_DIR/cineverse/cache\"
    sed -i "s#^JELLYFIN_DATA_DIR=.*#$DATA_DIR_SET#g;s#^JELLYFIN_LOG_DIR=.*#$LOG_DIR_SET#g;s#^JELLYFIN_CACHE_DIR=.*#$CACHE_DIR_SET#g" /etc/default/cineverse

    if [ "$JELLYFIN_DATA_DIR" == "/var/lib/cineverse" ]; then
        sed -i "s#/real/path/to/cineverse/transcodes#$TARGET_DIR/cineverse/transcodes#" /etc/cineverse/encoding.xml
    fi

    setDir

    if [ "$ENABLE" -eq 1 ]; then
        systemctl start cineverse.service
    fi
fi
